<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LayerCompatibility</name>
    <message>
        <location filename="../LayerCompatibility.js" line="+30"/>
        <source>Layer</source>
        <translation>Camada</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Compatibility</source>
        <translation>Compatibilidade</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Layer 0</source>
        <translation>Camada 0</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Layer 0 behaves like a regular layer (QCAD)</source>
        <translation>Camada 0 comporta-se como uma camada comum</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Layer 0 behaves differently (best compatibility)</source>
        <translation>A camada 0 comporta-se de forma diferente (melhor compatibilidade)</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Entities in blocks on layer 0 take on attributes and visibility of block reference.</source>
        <translation>Entidades em blocos na camada 0 utilizar os atributos e visibilidade de referência do bloco.</translation>
    </message>
    <message>
        <source>Entities in blocks on layer 0 take on attributes of block reference (compatibility)</source>
        <translation type="vanished">Entidades em blocos na camada 0 utilizar os atributos de referência do bloco (compatibilidade)</translation>
    </message>
</context>
</TS>
